@@ -536,7 +536,7 @@ bool Sweeper::HandleMouseEvent(const Lum::OS::MouseEvent& event)
   return false;
 }
 
-bool Sweeper::SetSize(size_t width, size_t height, size_t bombs)
+bool Sweeper::SetSize(unsigned long width, unsigned long height, unsigned long bombs)
 {
   if (width>sMaxWidth || height>sMaxHeight || bombs>width*height) {
     return false;
@@ -563,22 +563,22 @@ void Sweeper::SetOneButtonMode(bool set)
   oneButtonMode=set;
 }
 
-size_t Sweeper::GetAreaWidth() const
+unsigned long Sweeper::GetAreaWidth() const
 {
   return sWidth;
 }
 
-size_t Sweeper::GetAreaHeight() const
+unsigned long Sweeper::GetAreaHeight() const
 {
   return sHeight;
 }
 
-size_t Sweeper::GetMines() const
+unsigned long Sweeper::GetMines() const
 {
   return bombs;
 }
 
-size_t Sweeper::GetMinesPercent() const
+unsigned long Sweeper::GetMinesPercent() const
 {
   return Lum::Base::RoundDiv(bombs*100,sWidth*sHeight);
 }
