@@ -50,36 +50,36 @@ public:
 private:
   struct Cell
   {
-    bool   active; //< The cell is part of the game area and thus visible
-    bool   bomb;   //< Has a bomb
-    bool   open;   //< The cell has been uncovered
-    bool   marked; //< The cell is hidden but marked to have a bomb
-    size_t count;  //< Number of bombs in neigbourhood
+    bool         active; //< The cell is part of the game area and thus visible
+    bool         bomb;   //< Has a bomb
+    bool         open;   //< The cell has been uncovered
+    bool         marked; //< The cell is hidden but marked to have a bomb
+    unsigned int count;  //< Number of bombs in neigbourhood
   };
 
 private:
-  size_t               sWidth;
-  size_t               sHeight;
-  size_t               sMaxWidth;
-  size_t               sMaxHeight;
-  Lum::OS::FontRef     font;
-  Lum::OS::ColorRef    emptyColor;
-  Lum::OS::ColorRef    cellColor;
-  Lum::OS::ColorRef    lightColor;
-  Lum::OS::ColorRef    darkColor;
-  Lum::OS::ColorRef    textColor;
-  Lum::OS::ColorRef    bombColor;
-  Lum::OS::ColorRef    markColor;
-  Lum::Model::ULongRef status;
-  Lum::Model::LongRef  marks;
-  size_t               bombs;
-  Cell                 area[areaWidth][areaHeight];
-  Lum::Base::Timer     timer;
-  int                  mbdx; //< Position of mouse on button down
-  int                  mbdy; //< Position of mouse on button down
-  bool                 oneButtonMode;
-  Lum::OS::Bitmap      *game;
-  size_t               themeIndex;
+  unsigned long         sWidth;
+  unsigned long         sHeight;
+  unsigned long         sMaxWidth;
+  unsigned long         sMaxHeight;
+  Lum::OS::FontRef      font;
+  Lum::OS::ColorRef     emptyColor;
+  Lum::OS::ColorRef     cellColor;
+  Lum::OS::ColorRef     lightColor;
+  Lum::OS::ColorRef     darkColor;
+  Lum::OS::ColorRef     textColor;
+  Lum::OS::ColorRef     bombColor;
+  Lum::OS::ColorRef     markColor;
+  Lum::Model::ULongRef  status;
+  Lum::Model::LongRef   marks;
+  unsigned long         bombs;
+  Cell                  area[areaWidth][areaHeight];
+  Lum::Base::Timer      timer;
+  int                   mbdx; //< Position of mouse on button down
+  int                   mbdy; //< Position of mouse on button down
+  bool                  oneButtonMode;
+  Lum::OS::Bitmap       *game;
+  unsigned long         themeIndex;
 
 private:
   // Base class
@@ -125,13 +125,13 @@ public:
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
 
-  bool SetSize(size_t width, size_t height, size_t bombs);
+  bool SetSize(unsigned long width, unsigned long height, unsigned long bombs);
   void SetOneButtonMode(bool set);
 
-  size_t GetAreaWidth() const;
-  size_t GetAreaHeight() const;
-  size_t GetMines() const;
-  size_t GetMinesPercent() const;
+  unsigned long GetAreaWidth() const;
+  unsigned long GetAreaHeight() const;
+  unsigned long GetMines() const;
+  unsigned long GetMinesPercent() const;
 
   Lum::Model::ULong* GetStatusModel() const;
   Lum::Model::Long* GetMarksModel() const;
