@@ -246,6 +246,25 @@ public:
 typedef Lum::Model::StdRefTable<Theme,std::vector<Theme> > ThemesModel;
 typedef Lum::Base::Reference<ThemesModel>                  ThemesModelRef;
 
+class ThemesComparator : public ThemesModel::Comparator
+{
+public:
+  bool operator()(const Theme& a,
+                  const Theme& b,
+                  size_t column,
+                  bool ascending) const
+  {
+    assert(column==2);
+
+    if (ascending) {
+      return a.boxSize<b.boxSize;
+    }
+    else {
+      return a.boxSize>b.boxSize;
+    }
+  }
+};
+
 class ThemesModelPainter : public Lum::TableCellPainter
 {
 public:
@@ -285,10 +304,11 @@ private:
 public:
   SelectTheme()
   : okAction(new Lum::Model::Action),
-    list(new ThemesModel(themes,NULL)),
+    list(new ThemesModel(themes,new ThemesComparator())),
     selection(new Lum::Model::SingleLineSelection),
     result(L"")
   {
+    list->Sort(2);
     list->SetEmptyText(L"(No themes found)");
 
     okAction->Disable();
@@ -366,9 +386,9 @@ private:
   Lum::Model::ActionRef  themeAction;
 
 public:
-  Lum::Model::IntRef     horiz;
-  Lum::Model::IntRef     vert;
-  Lum::Model::IntRef     mines;
+  Lum::Model::ULongRef   horiz;
+  Lum::Model::ULongRef   vert;
+  Lum::Model::ULongRef   mines;
   Lum::Model::BooleanRef oneButtonMode;
   Lum::Model::StringRef  themeName;
 
@@ -378,9 +398,9 @@ public:
     mediumAction(new Lum::Model::Action()),
     bigAction(new Lum::Model::Action()),
     themeAction(new Lum::Model::Action()),
-    horiz(new Lum::Model::Int(sweeper->GetAreaWidth())),
-    vert(new Lum::Model::Int(sweeper->GetAreaHeight())),
-    mines(new Lum::Model::Int(sweeper->GetMinesPercent())),
+    horiz(new Lum::Model::ULong(sweeper->GetAreaWidth(),1,30)),
+    vert(new Lum::Model::ULong(sweeper->GetAreaHeight(),1,30)),
+    mines(new Lum::Model::ULong(sweeper->GetMinesPercent(),0,100)),
     oneButtonMode(new Lum::Model::Boolean(GetOneButtonMode())),
     themeName(new Lum::Model::String())
   {
@@ -389,10 +409,6 @@ public:
     Observe(bigAction);
     Observe(themeAction);
 
-    horiz->SetRange(1,30);
-    vert->SetRange(1,30);
-    mines->SetRange(0,100);
-
     themeName->Set(::themeName);
   }
 
@@ -671,7 +687,10 @@ public:
 
       if (sweeper->SetSize(settings.horiz->Get(),
                            settings.vert->Get(),
-                           Lum::Base::RoundDiv(settings.horiz->Get()*settings.vert->Get()*settings.mines->Get(),100))) {
+                           Lum::Base::RoundDiv(settings.horiz->Get()*
+                                               settings.vert->Get()*
+                                               settings.mines->Get(),
+                                               100))) {
         SetCurrentGame(sweeper->GetAreaWidth(),
                        sweeper->GetAreaHeight(),
                        sweeper->GetMines());
